::-webkit-scrollbar {
  height: 8px;
  width: 8px;
  background: #fff; }

::-webkit-scrollbar-corner {
  background: #fff; }

::-webkit-scrollbar-thumb {
  background: #4f80ff;
  -webkit-border-radius: 10px; }

html {
  background: #fff; }

body,
h1,
h2,
h3,
h4 {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif; }

.login {
  background: #4f80ff; }
  .login .content-wrapper,
  .login .messages {
    background: #4f80ff; }
  .login .button {
    background: #fff;
    color: #4f80ff; }
    .login .button:hover {
      background: rgba(255, 255, 255, 0.5);
      color: #4f80ff; }

a {
  color: #4f80ff; }
  a:hover {
    color: #4f78db; }

body.nav-open .wrapper {
  padding-left: 200px; }

.wrapper {
  padding-left: 200px;
  border-right: 1px solid #e0e0e0; }
  .wrapper .logo {
    width: auto;
    max-width: 170px;
    height: 36px;
    margin: 40px 20px 20px;
    padding: 0;
    color: #fff; }
  .wrapper .nav-wrapper {
    width: 200px;
    background: #4f80ff; }
    .wrapper .nav-wrapper .inner {
      width: 200px;
      background: #4f80ff; }
  .wrapper .nav-main {
    position: relative;
    top: auto; }
    .wrapper .nav-main .menu-item a {
      display: block;
      color: rgba(255, 255, 255, 0.65);
      padding: 10px 15px;
      font-size: 14px;
      font-weight: normal; }
      .wrapper .nav-main .menu-item a:hover, .wrapper .nav-main .menu-item a:focus {
        background-color: transparent;
        color: white;
        text-shadow: none; }
      .wrapper .nav-main .menu-item a.dl-active {
        background: #4f78db; }
    .wrapper .nav-main .menu-item.menu-active {
      background: #fff;
      text-shadow: none;
      border-radius: 0 3px 3px 0;
      margin-right: 10px; }
      .wrapper .nav-main .menu-item.menu-active > a {
        border-left-color: white;
        color: #4f80ff; }
    .wrapper .nav-main .footer {
      width: 200px;
      color: rgba(255, 255, 255, 0.65); }
    .wrapper .nav-main .account {
      background: transparent;
      color: rgba(255, 255, 255, 0.65); }
      .wrapper .nav-main .account:hover {
        outline: none;
        background-color: transparent;
        color: #fff;
        text-shadow: none; }
      .wrapper .nav-main .account .avatar {
        border-radius: 100%; }
        .wrapper .nav-main .account .avatar img {
          border-radius: 100%; }
        .wrapper .nav-main .account .avatar::before {
          border: 0; }
    .wrapper .nav-main .footer-submenu {
      background: transparent; }
      .wrapper .nav-main .footer-submenu a {
        display: block;
        color: rgba(255, 255, 255, 0.65);
        padding: 10px 20px;
        font-size: 14px;
        font-weight: normal; }
        .wrapper .nav-main .footer-submenu a:hover, .wrapper .nav-main .footer-submenu a:focus {
          background-color: transparent;
          color: white;
          text-shadow: none; }
  .wrapper .nav-submenu {
    background: #4f78db; }
    .wrapper .nav-submenu h2 {
      width: 200px;
      color: #fff; }
    .wrapper .nav-submenu ul {
      margin: 0;
      padding: 15px 0; }
    .wrapper .nav-submenu .footer {
      margin-left: -20px; }
    .wrapper .nav-submenu .menu-item.menu-active {
      background: transparent; }
      .wrapper .nav-submenu .menu-item.menu-active a {
        color: #fff;
        border-color: transparent; }
  .wrapper li.submenu-active {
    background: #4f78db; }
    .wrapper li.submenu-active > a {
      text-shadow: none; }
    .wrapper li.submenu-active .nav-submenu {
      box-shadow: 1px 0 1px rgba(39, 39, 39, 0.15);
      width: 200px;
      left: 200px;
      padding: 0 0 1.5em; }
  .wrapper .nav-search {
    margin: 20px 10px; }
    .wrapper .nav-search input {
      border-radius: 60px;
      border: 1px solid rgba(255, 255, 255, 0.2);
      background-color: transparent;
      color: #3c3c3c;
      padding: 8px 30px 8px 15px;
      box-shadow: none; }
      .wrapper .nav-search input::-webkit-input-placeholder {
        color: rgba(255, 255, 255, 0.65); }
      .wrapper .nav-search input:-moz-placeholder {
        color: rgba(255, 255, 255, 0.65); }
      .wrapper .nav-search input::-moz-placeholder {
        color: rgba(255, 255, 255, 0.65); }
      .wrapper .nav-search input:-ms-input-placeholder {
        color: rgba(255, 255, 255, 0.65); }
      .wrapper .nav-search input:hover {
        border-color: rgba(255, 255, 255, 0.4); }
      .wrapper .nav-search input:focus {
        border-color: white;
        background: white; }
    .wrapper .nav-search button {
      background-color: transparent;
      width: 3em;
      height: 100%;
      color: rgba(255, 255, 255, 0.65); }
      .wrapper .nav-search button::before {
        line-height: 34px; }
      .wrapper .nav-search button:hover {
        color: white; }
  .wrapper header {
    padding: 20px;
    background: #fafafa;
    border-bottom: 1px solid #e0e0e0;
    color: #838383; }
    .wrapper header.no-border {
      border: 0; }
    .wrapper header.nice-padding {
      padding-left: 40px;
      padding-right: 40px; }
    .wrapper header.no-v-padding {
      padding-top: 0;
      padding-bottom: 0; }
    .wrapper header.hasform h1 {
      margin: 0;
      padding: 0; }
    .wrapper header.hasform .row {
      -webkit-box-pack: justify;
          -ms-flex-pack: justify;
              justify-content: space-between; }
      .wrapper header.hasform .row .left {
        -webkit-box-flex: 2;
            -ms-flex: 2;
                flex: 2;
        display: -webkit-box;
        display: -ms-flexbox;
        display: flex;
        -webkit-box-align: center;
            -ms-flex-align: center;
                align-items: center; }
      .wrapper header.hasform .row .right {
        margin: 0;
        display: -webkit-box;
        display: -ms-flexbox;
        display: flex;
        -webkit-box-align: center;
            -ms-flex-align: center;
                align-items: center; }
    .wrapper header.hasform .fields {
      margin: 0; }
      .wrapper header.hasform .fields > li {
        padding: 0; }
    .wrapper header.hasform .input.icon-search::before {
      top: 9px;
      font-size: 18px; }
    .wrapper header.hasform input[type=text],
    .wrapper header.hasform select {
      font-size: 14px;
      border-width: 1px;
      padding: 8px 15px 8px 35px; }
    .wrapper header.tab-merged .row {
      position: relative; }
      .wrapper header.tab-merged .row .right {
        position: absolute;
        top: 50%;
        right: 0;
        -webkit-box-flex: 1;
            -ms-flex: auto;
                flex: auto;
        width: auto;
        margin-top: -22px;
        padding: 10px 0 10px 10px;
        background: #fafafa; }
        .wrapper header.tab-merged .row .right::before {
          content: '';
          position: absolute;
          top: 0;
          left: 0;
          bottom: 0;
          width: 30px;
          margin-left: -30px;
          background-image: -webkit-linear-gradient(left, rgba(250, 250, 250, 0) 0%, #fafafa 100%);
          background-image: linear-gradient(to right, rgba(250, 250, 250, 0) 0%, #fafafa 100%);
          display: block; }
    .wrapper header.merged .left {
      -webkit-box-flex: 1;
          -ms-flex: 1;
              flex: 1;
      white-space: nowrap;
      text-overflow: ellipsis;
      overflow: hidden; }
    .wrapper header.merged .right {
      -webkit-box-flex: 0;
          -ms-flex: 0 0 450px;
              flex: 0 0 450px; }
    .wrapper header.merged h1 {
      color: #838383;
      text-transform: capitalize;
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex;
      font-weight: 400;
      font-size: 18px;
      -webkit-box-align: baseline;
          -ms-flex-align: baseline;
              align-items: baseline; }
      .wrapper header.merged h1 span {
        color: #3c3c3c;
        text-transform: capitalize;
        font-weight: 600;
        -webkit-box-ordinal-group: -1;
            -ms-flex-order: -2;
                order: -2;
        font-size: 24px;
        margin-right: 10px; }
    .wrapper header h1 {
      color: #3c3c3c;
      text-transform: capitalize;
      font-weight: 600;
      font-size: 24px; }
      .wrapper header h1 span {
        font-size: 18px;
        font-weight: 400;
        color: #838383; }
      .wrapper header h1.icon::before {
        display: none; }
    .wrapper header .button {
      background: #4f80ff; }
      .wrapper header .button:hover {
        background: #4f78db; }
      .wrapper header .button.unbutton {
        background-color: transparent;
        border: 0;
        color: inherit; }
    .wrapper header .row {
      margin: 0;
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-pack: justify;
          -ms-flex-pack: justify;
              justify-content: space-between; }
      .wrapper header .row .left {
        -webkit-box-flex: 2;
            -ms-flex: 2;
                flex: 2; }
      .wrapper header .row .right {
        -webkit-box-flex: 1;
            -ms-flex: 1;
                flex: 1; }
      .wrapper header .row .col9,
      .wrapper header .row .col3 {
        width: 100%;
        margin: 0;
        padding: 0; }
      .wrapper header .row .right {
        margin: 0;
        display: -webkit-box;
        display: -ms-flexbox;
        display: flex;
        -webkit-box-pack: end;
            -ms-flex-pack: end;
                justify-content: flex-end;
        -webkit-box-align: center;
            -ms-flex-align: center;
                align-items: center; }
        .wrapper header .row .right .privacy-indicator,
        .wrapper header .row .right .lock-indicator {
          margin-left: 10px; }
  .wrapper footer {
    border-top: 1px solid #f4f4f4;
    background: rgba(255, 255, 255, 0.95);
    color: #3c3c3c;
    padding: 10px 30px;
    width: calc(100% - 200px);
    margin: 0; }
    .wrapper footer a:hover {
      color: #4f80ff; }
  .wrapper .breadcrumb {
    background: #fafafa;
    margin: 0;
    padding: 10px 0;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center; }
    .wrapper .breadcrumb li {
      position: relative;
      margin: 0 5px 0 0;
      padding: 0;
      float: none;
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-align: center;
          -ms-flex-align: center;
              align-items: center; }
      .wrapper .breadcrumb li:hover {
        background: transparent; }
      .wrapper .breadcrumb li.home a {
        width: auto; }
        .wrapper .breadcrumb li.home a::after {
          width: 16px; }
      .wrapper .breadcrumb li a,
      .wrapper .breadcrumb li span {
        width: auto;
        display: -webkit-box;
        display: -ms-flexbox;
        display: flex;
        -webkit-box-align: center;
            -ms-flex-align: center;
                align-items: center;
        color: #838383;
        max-width: none;
        white-space: nowrap;
        text-overflow: ellipsis;
        overflow: hidden;
        line-height: 20px;
        padding-right: 0; }
        .wrapper .breadcrumb li a:hover,
        .wrapper .breadcrumb li span:hover {
          color: #4f80ff; }
        .wrapper .breadcrumb li a::before,
        .wrapper .breadcrumb li span::before {
          width: 20px;
          line-height: 20px;
          font-size: 16px;
          margin: 0 5px 0 0; }
        .wrapper .breadcrumb li a::after,
        .wrapper .breadcrumb li span::after {
          position: static;
          top: auto;
          right: auto;
          margin: 0 0 0 5px;
          padding: 0;
          color: #838383;
          font-size: 16px;
          line-height: 20px;
          width: 20px; }
  .wrapper .tab-nav,
  .wrapper .tab-nav.merged {
    margin-top: -1px;
    background: #fafafa;
    border-bottom: 1px solid #e5e5e5;
    padding: 0 40px 0; }
    .wrapper .tab-nav li,
    .wrapper .tab-nav.merged li {
      margin: 0;
      width: auto; }
      .wrapper .tab-nav li a,
      .wrapper .tab-nav.merged li a {
        padding: 10px 20px 12px;
        position: relative;
        top: 1px;
        background-color: transparent;
        border: 0;
        color: #838383;
        border: 1px solid transparent;
        text-transform: none;
        font-weight: 400; }
        .wrapper .tab-nav li a::before,
        .wrapper .tab-nav.merged li a::before {
          display: none; }
        .wrapper .tab-nav li a:hover,
        .wrapper .tab-nav.merged li a:hover {
          color: #4f80ff; }
      .wrapper .tab-nav li.active a,
      .wrapper .tab-nav.merged li.active a {
        border: 0;
        background: #fff;
        border: 1px solid #e5e5e5;
        border-bottom-color: #fff;
        color: #4f80ff;
        font-weight: 500; }
  .wrapper .tab-content section {
    padding: 0; }
    .wrapper .tab-content section > .fields {
      padding: 0 40px; }
  .wrapper .page-explorer .listing .index {
    background: #fff; }
    .wrapper .page-explorer .listing .index .title h2 {
      color: #272727; }
  .wrapper .content {
    padding: 0 0 50px; }
  .wrapper .content-wrapper {
    border-bottom: 0; }
  .wrapper .summary {
    background: #f4f4f4;
    border-bottom: 1px solid #e5e5e5;
    margin-bottom: 20px;
    padding: 20px 0; }
    .wrapper .summary ul.stats {
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-pack: justify;
          -ms-flex-pack: justify;
              justify-content: space-between;
      -webkit-box-align: center;
          -ms-flex-align: center;
              align-items: center; }
      .wrapper .summary ul.stats li {
        width: auto;
        -webkit-box-flex: 1;
            -ms-flex: 1;
                flex: 1;
        margin: 0;
        padding: 0; }
        .wrapper .summary ul.stats li::before {
          font-size: 70px; }
        .wrapper .summary ul.stats li a {
          font-size: 16px; }
          .wrapper .summary ul.stats li a span {
            font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
            font-size: 50px;
            font-weight: 600; }
  .wrapper ul.sequence {
    padding: 15px;
    background: #fafafa;
    border-radius: 5px;
    border: 1px solid #f4f4f4; }
    .wrapper ul.sequence .sequence {
      padding-bottom: 70px;
      background: #f4f4f4;
      border: 1px solid #e5e5e5; }
      .wrapper ul.sequence .sequence + button {
        margin-top: -90px;
        margin-left: 20px; }
  .wrapper li.sequence-member {
    background: none;
    border: 0;
    margin: 0 0 15px; }
    .wrapper li.sequence-member .sequence-member-inner {
      background: #fff;
      border: 1px solid #e5e5e5;
      border-radius: 3px;
      padding: 15px 25px; }
      .wrapper li.sequence-member .sequence-member-inner .sequence-type-list .sequence-container-inner {
        width: 100%; }
        .wrapper li.sequence-member .sequence-member-inner .sequence-type-list .sequence-container-inner .sequence-member {
          border-radius: 3px;
          margin: 0 0 15px; }
          .wrapper li.sequence-member .sequence-member-inner .sequence-type-list .sequence-container-inner .sequence-member:last-child {
            margin: 0; }
          .wrapper li.sequence-member .sequence-member-inner .sequence-type-list .sequence-container-inner .sequence-member .sequence-member-inner {
            padding: 15px 25px; }
    .wrapper li.sequence-member .sequence-controls {
      position: relative;
      z-index: 1;
      top: auto;
      left: auto;
      right: auto;
      opacity: 1;
      visibility: visible;
      border-color: #e5e5e5;
      background-color: #fff;
      border-radius: 3px 3px 0 0;
      margin: 0 0 -3px;
      padding: 0; }
      .wrapper li.sequence-member .sequence-controls h3 label {
        text-transform: uppercase;
        padding: 0 10px;
        color: #4f80ff;
        font-weight: 600; }
      .wrapper li.sequence-member .sequence-controls .button-group {
        border-radius: 2px;
        overflow: hidden;
        top: 1px;
        right: 1px;
        position: relative; }
    .wrapper li.sequence-member:hover {
      background: none;
      border: 0; }
    .wrapper li.sequence-member .struct-block .fields {
      width: 100%; }
    .wrapper li.sequence-member .fields > li {
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex; }
      .wrapper li.sequence-member .fields > li > * {
        -webkit-box-flex: 1;
            -ms-flex: 1;
                flex: 1; }
      .wrapper li.sequence-member .fields > li > label {
        -webkit-box-flex: 0;
            -ms-flex: 0 0 150px;
                flex: 0 0 150px;
        text-align: right;
        padding-top: 14px; }
    .wrapper li.sequence-member .fields {
      width: 100%; }
    .wrapper li.sequence-member .stream-menu {
      margin-top: 15px; }
    .wrapper li.sequence-member .sequence-container {
      width: 100%; }
      .wrapper li.sequence-member .sequence-container .sequence-controls {
        position: absolute;
        top: 2px;
        right: 2px;
        border-radius: 2px;
        opacity: 0; }
      .wrapper li.sequence-member .sequence-container:hover .sequence-controls {
        opacity: 1; }
  .wrapper .fields > li, .wrapper .field-col {
    padding: 10px 0; }
  .wrapper .objects {
    padding: 40px; }
  .wrapper .object {
    margin-top: 20px;
    padding-left: 0;
    padding-right: 0; }
    .wrapper .object:first-child {
      margin-top: 0; }
    .wrapper .object > h2 {
      top: 8px;
      position: absolute;
      background: transparent;
      color: #3c3c3c;
      text-transform: uppercase;
      padding: 0;
      font-size: 15px;
      font-weight: 600;
      margin: 0;
      line-height: 32px;
      height: 32px;
      overflow: visible;
      border-bottom: 1px solid #e0e0e0; }
      .wrapper .object > h2::before {
        display: none; }
      .wrapper .object > h2 label {
        background: #fff;
        padding: 8px 0 4px;
        display: inline-block;
        border-bottom: 2px solid #4f80ff; }
        .wrapper .object > h2 label::before {
          position: absolute;
          right: 0;
          top: 0;
          left: auto;
          width: 24px;
          height: 24px;
          line-height: 24px;
          border-radius: 100%;
          background: none;
          color: #fff;
          font-size: 18px; }
    .wrapper .object.collapsible > h2 label::before {
      color: #4f80ff; }
    .wrapper .object fieldset {
      margin: 0;
      padding: 40px 0 0;
      width: 100%;
      max-width: none;
      float: none; }
    .wrapper .object.full .object-help {
      width: 200px; }
    .wrapper .object.full fieldset {
      width: calc(100% - 200px);
      padding: 40px 0 0;
      margin: 0; }
    .wrapper .object.full input,
    .wrapper .object.full textarea,
    .wrapper .object.full .richtext {
      font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
      padding: 20px 20px;
      border-width: 0 1px 0 0;
      font-size: 16px;
      background: #fafafa; }
      .wrapper .object.full input:focus,
      .wrapper .object.full textarea:focus,
      .wrapper .object.full .richtext:focus {
        background: #fafbfe; }
    .wrapper .object.full.title input,
    .wrapper .object.full.title textarea,
    .wrapper .object.full.title .richtext {
      font-size: 32px; }
    .wrapper .object.stream-field > fieldset {
      min-width: 0; }
    .wrapper .object.empty > h2 {
      border-bottom: 1px solid #e0e0e0; }
    .wrapper .object.empty .add {
      margin: 60px 0 0; }
      .wrapper .object.empty .add .button {
        border-radius: 3px;
        overflow: visible;
        background-color: #4f80ff;
        font-size: 0.9em;
        width: auto; }
        .wrapper .object.empty .add .button::before {
          position: absolute;
          padding: 0;
          line-height: 35px;
          font-size: 1rem;
          width: 2em;
          background-color: rgba(0, 0, 0, 0.2); }
        .wrapper .object.empty .add .button:hover {
          background-color: #4f78db; }
          .wrapper .object.empty .add .button:hover::before {
            background-color: rgba(0, 0, 0, 0.2); }
    .wrapper .object .multiple {
      width: 100%;
      max-width: none;
      padding-left: 0;
      padding-right: 0; }
      .wrapper .object .multiple > li {
        padding: 20px; }
        .wrapper .object .multiple > li .controls {
          top: 1px;
          right: -1px; }
      .wrapper .object .multiple .fields > li {
        padding: 0; }
  .wrapper .field-content {
    width: 100%; }
  .wrapper .field-row {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    margin: 0 -15px; }
    .wrapper .field-row .field-col {
      -webkit-box-flex: 1;
          -ms-flex: 1;
              flex: 1;
      width: auto;
      margin: 0 15px; }
      .wrapper .field-row .field-col .field-content {
        padding: 0; }
  .wrapper .label-above .field {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
        -ms-flex-direction: column;
            flex-direction: column; }
    .wrapper .label-above .field label,
    .wrapper .label-above .field .field-content {
      width: 100%; }
  .wrapper .list-controls {
    top: 5px;
    right: 5px; }
  .wrapper .page-editor .content-wrapper {
    margin-bottom: 0; }
  .wrapper .stream-menu {
    border-radius: 4px;
    margin: 20px 0;
    box-shadow: none;
    position: relative;
    background-color: #3c3c3c;
    opacity: 1; }
    .wrapper .stream-menu button {
      color: rgba(255, 255, 255, 0.65); }
      .wrapper .stream-menu button:hover {
        background: #4f80ff; }
    .wrapper .stream-menu .toggle {
      color: #ff6b65; }
      .wrapper .stream-menu .toggle:hover {
        color: #de6564; }
    .wrapper .stream-menu.stream-menu-closed .toggle {
      color: #4f80ff; }
      .wrapper .stream-menu.stream-menu-closed .toggle:hover, .wrapper .stream-menu.stream-menu-closed .toggle:active {
        color: #4f78db; }
  .wrapper .richtext {
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
    box-shadow: none; }
    .wrapper .richtext:focus, .wrapper .richtext:hover {
      box-shadow: none; }
  .wrapper .nice-padding {
    padding-left: 40px;
    padding-right: 40px; }
  .wrapper .listing {
    margin: 0; }
    .wrapper .listing .title h2 a:hover {
      color: #4f80ff; }
    .wrapper .listing.full-width th {
      background: #f4f4f4; }
      .wrapper .listing.full-width th a:hover,
      .wrapper .listing.full-width th a:hover:before {
        color: #4f80ff; }
    .wrapper .listing.full-width + .pagination {
      margin-top: 0;
      border-top: 0;
      padding: 30px 50px 0; }
    .wrapper .listing.full-width td:first-child,
    .wrapper .listing.full-width th:first-child {
      padding-left: 40px; }
      .wrapper .listing.full-width td:first-child:first-child.ord,
      .wrapper .listing.full-width th:first-child:first-child.ord {
        padding: 0;
        text-align: center; }
    .wrapper .listing.full-width .help-info {
      border-radius: 0;
      margin: -20px -10px -20px -40px; }
    .wrapper .listing .table-headers {
      border-bottom: 1px solid #e5e5e5; }
    .wrapper .listing .index {
      background: #fafbfe; }
    .wrapper .listing th,
    .wrapper .listing td {
      padding: 20px 10px; }
      .wrapper .listing th.children, .wrapper .listing th.no-children,
      .wrapper .listing td.children,
      .wrapper .listing td.no-children {
        padding: 0; }
    .wrapper .listing th {
      padding-top: 7px;
      padding-bottom: 7px; }
    .wrapper .listing tbody {
      border-bottom: 1px solid #f4f4f4; }
    .wrapper .listing tbody tr {
      border-top: 1px solid #f4f4f4; }
      .wrapper .listing tbody tr:hover {
        background-color: #fafbfe; }
        .wrapper .listing tbody tr:hover .title .actions {
          opacity: 1;
          -webkit-transition: 0.15s;
          transition: 0.15s; }
        .wrapper .listing tbody tr:hover .children {
          background-color: #4f80ff; }
          .wrapper .listing tbody tr:hover .children:hover {
            background-color: #4f78db; }
      .wrapper .listing tbody tr .title {
        position: relative; }
        .wrapper .listing tbody tr .title .actions {
          position: absolute;
          top: 0;
          bottom: 0;
          right: 0;
          margin: 0;
          display: -webkit-box;
          display: -ms-flexbox;
          display: flex;
          -webkit-box-align: center;
              -ms-flex-align: center;
                  align-items: center;
          padding: 0 0 0 5px;
          background: #fafbfe;
          opacity: 0;
          -webkit-transition: 0.35s;
          transition: 0.35s; }
          .wrapper .listing tbody tr .title .actions > li {
            margin: 0; }
          .wrapper .listing tbody tr .title .actions::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            bottom: 0;
            width: 30px;
            margin-left: -30px;
            background-image: -webkit-linear-gradient(left, rgba(250, 251, 254, 0) 0%, #fafbfe 100%);
            background-image: linear-gradient(to right, rgba(250, 251, 254, 0) 0%, #fafbfe 100%);
            display: block; }
    .wrapper .listing .handle {
      display: inline-block; }
    .wrapper .listing .children a {
      color: #4f80ff;
      display: block; }
      .wrapper .listing .children a::before {
        font-size: 30px; }
    .wrapper .listing .no-children a:hover {
      color: #4f80ff; }
    .wrapper .listing .button-secondary {
      border-color: #4f80ff;
      color: #4f80ff; }
      .wrapper .listing .button-secondary:hover {
        background: #4f80ff;
        color: #fff; }
  .wrapper ul.listing {
    border-top: 1px solid #f4f4f4;
    margin-bottom: 20px; }
    .wrapper ul.listing > li {
      border-bottom: 1px solid #f4f4f4; }
  .wrapper .pagination {
    margin-top: 0;
    border-top: 0;
    padding: 30px 50px 0; }
  .wrapper .drop-zone {
    background: #f4f4f4;
    border: 1px solid #e5e5e5; }
  .wrapper .replace-file-input:hover button {
    background-color: #4f78db; }
  .wrapper .privacy-indicator .label-private::before,
  .wrapper .privacy-indicator .label-public::before,
  .wrapper .icon.teal {
    color: #4f78db; }
  .wrapper .status-tag {
    margin: 0 5px; }
  .wrapper form.status-tag:hover,
  .wrapper a.status-tag:hover,
  .wrapper a.status-tag.primary:hover {
    border-color: #4f80ff;
    color: #4f80ff;
    background-color: transparent; }

.tab-nav.merged {
  background-color: #4f80ff; }
  .tab-nav.merged a {
    background-color: rgba(255, 255, 255, 0.1);
    border-top-color: rgba(255, 255, 255, 0.1); }
  .tab-nav.merged li.active a {
    border-top-color: #fff;
    color: #4f80ff; }

.listing.images > li:hover img {
  border-color: #4f80ff; }

input,
textarea,
select,
.richtext,
.tagit {
  box-sizing: border-box;
  border-radius: 3px;
  width: 100%;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  box-shadow: inset 0 1px 1px rgba(60, 60, 60, 0.08);
  border: 1px solid #d3d3d3;
  padding: 13px 15px;
  background-color: #fff;
  color: #3c3c3c;
  font-size: 16px;
  font-weight: 300;
  outline: none; }
  input:focus,
  textarea:focus,
  select:focus,
  .richtext:focus,
  .tagit:focus {
    border-color: #4f80ff;
    background: #fafbfe;
    box-shadow: inset 0 1px 1px rgba(79, 128, 255, 0.15); }

input[type=checkbox]::before {
  border: 1px solid #d3d3d3;
  border-radius: 3px;
  box-shadow: inset 0 1px 1px rgba(60, 60, 60, 0.08);
  width: 21px;
  height: 22px;
  line-height: 23px;
  color: transparent;
  padding-left: 1px; }

input[type=checkbox]:checked::before {
  color: #4f80ff; }

input[type=radio]::before {
  border: 1px solid #d3d3d3;
  border-radius: 100%;
  box-shadow: inset 0 1px 1px rgba(60, 60, 60, 0.08);
  color: transparent;
  width: 16px;
  height: 16px; }

input[type=radio]:checked::before {
  color: #4f80ff; }

.error input,
.error textarea,
.error select,
.error .tagit {
  border-color: #ff6b65;
  background-color: #fef9f9; }

.error-message {
  color: #ff6b65; }

.full input,
.full textarea,
.full .richtext {
  box-shadow: none; }

.choice_field .input select ~ span:after,
.model_choice_field .input select ~ span:after,
.typed_choice_field .input select ~ span:after {
  line-height: 44px;
  width: 50px;
  font-size: 30px; }

.dropdown .dropdown-toggle {
  background: #4f80ff; }

.dropdown ul {
  background: #4f80ff; }
  .dropdown ul a:hover {
    background-color: #4f78db; }

.dropdown.open .dropdown-toggle, .dropdown:hover .dropdown-toggle {
  background-color: #4f78db; }

.dropdown.warning .dropdown-toggle {
  background-color: #dfbb6d; }

.dropdown.warning.open .dropdown-toggle, .dropdown.warning:hover .dropdown-toggle {
  background-color: #a98f59; }

.button {
  border-color: #4f80ff;
  background-color: #4f80ff; }
  .button:hover {
    border-color: #4f78db;
    background-color: #4f78db; }
  .button.warning {
    border-color: #ffd668;
    background: #ffd668; }
    .button.warning:hover {
      border-color: #dfbb6d;
      background: #dfbb6d; }
  .button.hover-no {
    border-color: #ff6b65;
    background: #ff6b65; }
    .button.hover-no:hover {
      border-color: #de6564;
      background: #de6564; }
  .button.unbutton {
    background-color: transparent;
    border: 0;
    color: inherit;
    box-shadow: none; }

.button-secondary {
  background: transparent;
  color: #4f80ff;
  border-color: #4f80ff; }

.help-block a {
  color: #4f80ff; }
  .help-block a:hover {
    color: #4f78db; }

.help-warning {
  background: #fff6eb; }

.explorer {
  width: 400px;
  left: 200px;
  margin-top: 0;
  position: fixed;
  top: 149px !important; }
  .explorer ul {
    background: #4f78db; }
    .explorer ul a {
      padding: 10px 15px 9px;
      font-size: 14px; }

.t-default .u-btn-current,
.t-inverted .u-btn-current {
  border-color: #838383;
  color: #838383;
  border-radius: 3px; }
  .t-default .u-btn-current:hover,
  .t-inverted .u-btn-current:hover {
    background: #838383;
    color: #fff;
    border-color: #838383; }

.page-explorer .listing td.updated,
.page-explorer .listing td.type {
  font-size: 12px;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis; }

.page-explorer .listing .index {
  background: #fafafa;
  border-bottom: 1px solid #e0e0e0;
  color: #838383; }
  .page-explorer .listing .index td {
    padding-top: 0;
    padding-bottom: 20px; }
  .page-explorer .listing .index .privacy-indicator {
    right: 30px;
    top: 10px; }
  .page-explorer .listing .index .title h2 {
    color: #3c3c3c;
    text-transform: capitalize;
    font-weight: 600;
    font-size: 24px; }
    .page-explorer .listing .index .title h2 a {
      color: #3c3c3c; }
      .page-explorer .listing .index .title h2 a:hover {
        color: #4f80ff;
        opacity: 1; }
  .page-explorer .listing .index .button {
    border-color: #4f80ff;
    color: #4f80ff; }
    .page-explorer .listing .index .button:hover {
      background: #4f78db;
      color: #fff;
      border-color: #4f78db; }
    .page-explorer .listing .index .button.bicolor {
      background: transparent;
      padding-left: 28px; }
      .page-explorer .listing .index .button.bicolor::before {
        background: none;
        margin-right: 0; }
      .page-explorer .listing .index .button.bicolor:hover {
        background: #4f78db;
        color: #fff;
        border-color: #4f78db; }

.page-editor .breadcrumb {
  margin: -20px 0 10px !important; }

.messages {
  background: #fafafa; }
  .messages ul li {
    padding-left: 40px;
    padding-right: 40px; }
  .messages .success {
    background: #3bccb2; }
  .messages .warning {
    background: #ffd668; }
  .messages .error {
    background: #ff6b65; }

.modal-content header {
  background: #4f80ff; }

.modal-content .modal-body {
  padding: 0; }

.help-block {
  border-radius: 0;
  padding: 20px 40px; }
  .help-block.help-info {
    background-color: #e6ecfe; }
    .help-block.help-info::before {
      color: #4f80ff; }
  .help-block.help-warning {
    background-color: #fff6eb; }
    .help-block.help-warning::before {
      color: #ffd668; }
  .help-block.help-critical {
    background-color: #fee9e9; }
    .help-block.help-critical::before {
      color: #ff6b65; }
  .help-block.help-info::before, .help-block.help-warning::before, .help-block.help-critical::before {
    left: 15px;
    top: 19px; }

.ui-buttonset .ui-state-default,
.ui-buttonset .ui-widget-content .ui-state-default,
.ui-buttonset .ui-widget-header .ui-state-default {
  border: 1px solid #d3d3d3;
  background: #fff;
  font-weight: normal;
  color: #3c3c3c; }

.ui-buttonset .ui-state-active,
.ui-buttonset .ui-widget-content .ui-state-active,
.ui-buttonset .ui-widget-header .ui-state-active {
  color: #fff;
  background: #4f80ff;
  border-color: #4f80ff; }

@media screen and (max-width: 799px) {
  body.nav-open .wrapper {
    padding: 0;
    -webkit-transform: none;
            transform: none; }
    body.nav-open .wrapper .content-wrapper {
      -webkit-transform: translateX(200px);
              transform: translateX(200px); }
    body.nav-open .wrapper .nav-wrapper {
      -webkit-transform: translateX(0);
              transform: translateX(0); }
  .nav-toggle.icon:before {
    color: #4f80ff; }
  .wrapper {
    padding: 0;
    border-right: 0; }
    .wrapper .nice-padding {
      padding-left: 20px;
      padding-right: 20px; }
    .wrapper .logo {
      margin: 30px 20px 30px; }
    .wrapper .nav-wrapper {
      width: 210px;
      margin: 0;
      position: fixed;
      top: 0;
      left: 0;
      z-index: 1;
      overflow: auto;
      -webkit-overflow-scrolling: touch;
      -webkit-transform: translateX(-210px);
              transform: translateX(-210px);
      -webkit-transition: 0.25s;
      transition: 0.25s; }
    .wrapper .nav-main .footer {
      margin-top: 20px; }
    .wrapper .nav-submenu {
      padding: 0 24px; }
      .wrapper .nav-submenu ul {
        padding: 5px 0; }
        .wrapper .nav-submenu ul .footer {
          display: none; }
    .wrapper .content-wrapper {
      position: relative;
      z-index: 2;
      -webkit-transition: 0.25s;
      transition: 0.25s; }
    .wrapper header {
      padding-top: 60px !important; }
      .wrapper header.nice-padding {
        padding-left: 20px;
        padding-right: 20px; }
    .wrapper .tab-nav {
      padding: 0 20px; }
    .wrapper .listing tbody tr .title .actions {
      position: static;
      display: block;
      opacity: 1;
      background: transparent;
      padding: 0;
      margin: 10px 0 0; }
      .wrapper .listing tbody tr .title .actions > li {
        margin-bottom: 5px; }
    .wrapper .objects {
      padding: 20px; }
    .wrapper footer {
      width: 100%;
      padding-left: 20px;
      padding-right: 20px; } }
